@@ -38,11 +38,11 @@ public:
 
     enum Roles {
         BatteryRole = Qt::UserRole,
-        UdiRole
+        UdiRole,
+        VendorRole,
+        ProductRole
     };
-
-    Q_INVOKABLE Solid::Battery *get(int index) const;
-    Q_INVOKABLE QString udi(int index) const;
+    Q_ENUM(Roles)
 
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
